@@ -261,10 +261,9 @@ class Desktop(MethodsInterface):
                 return False
 
     def userLogout(self, urLogin):
-        if self.clVars.GetBool('cl_desktop_elogind_set'):
-            return self.userLogoutByElogind(urLogin)
-        else:
-            return self.userLogoutBySession(urLogin)
+        # Используется завершение сессии, так loginctl прибивает
+        # сессию без завершающих скриптов
+        return self.userLogoutBySession(urLogin)
 
     def getElogindSessionId(self, urLogin):
         loginctl = getProgPath("/bin/loginctl")
